// This code implementation is the intellectual property of
// the GEANT4 collaboration.
//
// By copying, distributing or modifying the Program (or any work
// based on the Program) you indicate your acceptance of this statement,
// and all its terms.
//
// --------------------------------------------------------------
//      GEANT 4 - CSCG4Ex
// --------------------------------------------------------------
// Comments
//   Example program for CSC 2000
// --------------------------------------------------------------


#include "G4RunManager.hh"
#include "G4UImanager.hh"
#include "G4UIterminal.hh"
#include "G4UItcsh.hh"

#include "CSCG4ExDetectorConstruction.hh"
#include "CSCG4ExPhysicsList.hh"
#include "CSCG4ExPrimaryGeneratorAction.hh"
#include "CSCG4ExEventAction.hh"
#include "CSCG4ExTrackingAction.hh"

#ifdef G4VIS_USE
#include "CSCG4ExVisManager.hh"
#endif

int main(int argc,char** argv)
{
  // RunManager construction
  G4RunManager* runManager = new G4RunManager;

#ifdef G4VIS_USE
  // Visualization manager construction
  G4VisManager* visManager = new CSCG4ExVisManager();
  visManager->Initialize();
#endif

  // mandatory user initialization classes
  runManager->SetUserInitialization(new CSCG4ExDetectorConstruction);
  runManager->SetUserInitialization(new CSCG4ExPhysicsList);

  // initialize Geant4 kernel
  runManager->Initialize();

  // mandatory user action class
  runManager->SetUserAction(new CSCG4ExPrimaryGeneratorAction);

  // optional user action classes
  runManager->SetUserAction(new CSCG4ExEventAction);
  runManager->SetUserAction(new CSCG4ExTrackingAction);

  if(argc>1)
  // execute an argument macro file if exist
  {
    G4UImanager* UImanager = G4UImanager::GetUIpointer();
    G4String command = "/control/execute ";
    G4String fileName = argv[1];
    UImanager->ApplyCommand(command+fileName);
  }
  else
  // start interactive session
  {
    G4UIsession* session = new G4UIterminal(new G4UItcsh);
    session->SessionStart();
    delete session;
  }

#ifdef G4VIS_USE
  delete visManager;
#endif

  delete runManager;

  return 0;
}

