// This code implementation is the intellectual property of
// the GEANT4 collaboration.
//
// By copying, distributing or modifying the Program (or any work
// based on the Program) you indicate your acceptance of this statement,
// and all its terms.
//
#ifndef CSCG4ExDriftChamberHit_h
#define CSCG4ExDriftChamberHit_h 1

#include "G4VHit.hh"
#include "G4THitsCollection.hh"
#include "G4Allocator.hh"
#include "G4ThreeVector.hh"
#include "G4LogicalVolume.hh"
#include "G4Transform3D.hh"
#include "G4RotationMatrix.hh"

class CSCG4ExDriftChamberHit : public G4VHit
{
  public:

      CSCG4ExDriftChamberHit();
      CSCG4ExDriftChamberHit(G4int z);
      virtual ~CSCG4ExDriftChamberHit();
      CSCG4ExDriftChamberHit(const CSCG4ExDriftChamberHit &right);
      const CSCG4ExDriftChamberHit& operator=(const CSCG4ExDriftChamberHit &right);
      int operator==(const CSCG4ExDriftChamberHit &right) const;

      inline void *operator new(size_t);
      inline void operator delete(void *aHit);

      virtual void Draw();
      virtual void Print();

  private:
      G4int layerID;
      G4double time;
      G4ThreeVector localPos;
      G4ThreeVector worldPos;

  public:
      inline void SetLayerID(G4int z) { layerID = z; }
      inline G4int GetLayerID() const { return layerID; }
      inline void SetTime(G4double t) { time = t; }
      inline G4double GetTime() const { return time; }
      inline void SetLocalPos(G4ThreeVector xyz) { localPos = xyz; }
      inline G4ThreeVector GetLocalPos() const { return localPos; }
      inline void SetWorldPos(G4ThreeVector xyz) { worldPos = xyz; }
      inline G4ThreeVector GetWorldPos() const { return worldPos; }
};

typedef G4THitsCollection<CSCG4ExDriftChamberHit> CSCG4ExDriftChamberHitsCollection;

extern G4Allocator<CSCG4ExDriftChamberHit> CSCG4ExDriftChamberHitAllocator;

inline void* CSCG4ExDriftChamberHit::operator new(size_t)
{
  void* aHit;
  aHit = (void*)CSCG4ExDriftChamberHitAllocator.MallocSingle();
  return aHit;
}

inline void CSCG4ExDriftChamberHit::operator delete(void* aHit)
{
  CSCG4ExDriftChamberHitAllocator.FreeSingle((CSCG4ExDriftChamberHit*) aHit);
}

#endif


