// This code implementation is the intellectual property of
// the GEANT4 collaboration.
//
// By copying, distributing or modifying the Program (or any work
// based on the Program) you indicate your acceptance of this statement,
// and all its terms.
//
#ifndef CSCG4ExEmCalorimeterHit_h
#define CSCG4ExEmCalorimeterHit_h 1

#include "G4VHit.hh"
#include "G4THitsCollection.hh"
#include "G4Allocator.hh"
#include "G4ThreeVector.hh"
#include "G4LogicalVolume.hh"
#include "G4Transform3D.hh"
#include "G4RotationMatrix.hh"

class CSCG4ExEmCalorimeterHit : public G4VHit
{
  public:

      CSCG4ExEmCalorimeterHit();
      CSCG4ExEmCalorimeterHit(G4int z);
      virtual ~CSCG4ExEmCalorimeterHit();
      CSCG4ExEmCalorimeterHit(const CSCG4ExEmCalorimeterHit &right);
      const CSCG4ExEmCalorimeterHit& operator=(const CSCG4ExEmCalorimeterHit &right);
      int operator==(const CSCG4ExEmCalorimeterHit &right) const;

      inline void *operator new(size_t);
      inline void operator delete(void *aHit);

      virtual void Draw();
      virtual void Print();

  private:
      G4int cellID;
      G4double edep;
      G4ThreeVector pos;
      G4RotationMatrix rot;
      const G4LogicalVolume* pLogV;

  public:
      inline void SetCellID(G4int z) { cellID = z; }
      inline G4int GetCellID() const { return cellID; }
      inline void SetEdep(G4double de) { edep = de; }
      inline void AddEdep(G4double de) { edep += de; }
      inline G4double GetEdep() const { return edep; }
      inline void SetPos(G4ThreeVector xyz) { pos = xyz; }
      inline G4ThreeVector GetPos() const { return pos; }
      inline void SetRot(G4RotationMatrix rmat) { rot = rmat; }
      inline G4RotationMatrix GetRot() const { return rot; }
      inline void SetLogV(G4LogicalVolume* val) { pLogV = val; }
      inline const G4LogicalVolume* GetLogV() const { return pLogV; }
};

typedef G4THitsCollection<CSCG4ExEmCalorimeterHit> CSCG4ExEmCalorimeterHitsCollection;

extern G4Allocator<CSCG4ExEmCalorimeterHit> CSCG4ExEmCalorimeterHitAllocator;

inline void* CSCG4ExEmCalorimeterHit::operator new(size_t)
{
  void* aHit;
  aHit = (void*)CSCG4ExEmCalorimeterHitAllocator.MallocSingle();
  return aHit;
}

inline void CSCG4ExEmCalorimeterHit::operator delete(void* aHit)
{
  CSCG4ExEmCalorimeterHitAllocator.FreeSingle((CSCG4ExEmCalorimeterHit*) aHit);
}

#endif


