// This code implementation is the intellectual property of
// the GEANT4 collaboration.
//
// By copying, distributing or modifying the Program (or any work
// based on the Program) you indicate your acceptance of this statement,
// and all its terms.
//
#ifndef CSCG4ExHodoscopeHit_h
#define CSCG4ExHodoscopeHit_h 1

#include "G4VHit.hh"
#include "G4THitsCollection.hh"
#include "G4Allocator.hh"
#include "G4ThreeVector.hh"
#include "G4LogicalVolume.hh"
#include "G4Transform3D.hh"
#include "G4RotationMatrix.hh"

class CSCG4ExHodoscopeHit : public G4VHit
{
  public:

      CSCG4ExHodoscopeHit(G4int i,G4double t);
      virtual ~CSCG4ExHodoscopeHit();
      CSCG4ExHodoscopeHit(const CSCG4ExHodoscopeHit &right);
      const CSCG4ExHodoscopeHit& operator=(const CSCG4ExHodoscopeHit &right);
      int operator==(const CSCG4ExHodoscopeHit &right) const;


      inline void *operator new(size_t);
      inline void operator delete(void*aHit);

      void Draw();
      void Print();

  private:
      G4int id;
      G4double time;
      G4ThreeVector pos;
      G4RotationMatrix rot;
      const G4LogicalVolume* pLogV;

  public:
      inline G4int GetID() const { return id; }
      inline G4double GetTime() const { return time; }
      inline void SetTime(G4double val) { time = val; }
      inline void SetPos(G4ThreeVector xyz) { pos = xyz; }
      inline G4ThreeVector GetPos() const { return pos; }
      inline void SetRot(G4RotationMatrix rmat) { rot = rmat; }
      inline G4RotationMatrix GetRot() const { return rot; }
      inline void SetLogV(G4LogicalVolume* val) { pLogV = val; }
      inline const G4LogicalVolume* GetLogV() const { return pLogV; }

};

typedef G4THitsCollection<CSCG4ExHodoscopeHit> CSCG4ExHodoscopeHitsCollection;

extern G4Allocator<CSCG4ExHodoscopeHit> CSCG4ExHodoscopeHitAllocator;

inline void* CSCG4ExHodoscopeHit::operator new(size_t)
{
  void* aHit;
  aHit = (void*)CSCG4ExHodoscopeHitAllocator.MallocSingle();
  return aHit;
}

inline void CSCG4ExHodoscopeHit::operator delete(void*aHit)
{
  CSCG4ExHodoscopeHitAllocator.FreeSingle((CSCG4ExHodoscopeHit*) aHit);
}

#endif


