// This code implementation is the intellectual property of
// the GEANT4 collaboration.
//
// By copying, distributing or modifying the Program (or any work
// based on the Program) you indicate your acceptance of this statement,
// and all its terms.
//
#include "CSCG4ExDriftChamber.hh"
#include "CSCG4ExDriftChamberHit.hh"
#include "G4HCofThisEvent.hh"
#include "G4TouchableHistory.hh"
#include "G4Track.hh"
#include "G4Step.hh"
#include "G4SDManager.hh"
#include "G4Navigator.hh"
#include "G4ios.hh"

CSCG4ExDriftChamber::CSCG4ExDriftChamber(G4String name)
:G4VSensitiveDetector(name)
{
  G4String HCname;
  collectionName.insert(HCname="driftChamberColl");
  HCID = -1;
}

CSCG4ExDriftChamber::~CSCG4ExDriftChamber(){;}

void CSCG4ExDriftChamber::Initialize(G4HCofThisEvent*HCE)
{
  hitsCollection = new CSCG4ExDriftChamberHitsCollection
                   (SensitiveDetectorName,collectionName[0]); 
  if(HCID<0)
  { HCID = G4SDManager::GetSDMpointer()->GetCollectionID(hitsCollection); }
  HCE->AddHitsCollection(HCID,hitsCollection);
}

G4bool CSCG4ExDriftChamber::ProcessHits(G4Step*aStep,G4TouchableHistory*ROhist)
{
  G4double charge = aStep->GetTrack()->GetDefinition()->GetPDGCharge();
  if(charge==0.) return true;

  G4StepPoint* preStepPoint = aStep->GetPreStepPoint();
  G4TouchableHistory* theTouchable
    = (G4TouchableHistory*)(preStepPoint->GetTouchable());
  G4VPhysicalVolume* theMotherPhysical = theTouchable->GetVolume(1); // mother
  G4int copyNo = theMotherPhysical->GetCopyNo();
  G4ThreeVector worldPos = preStepPoint->GetPosition();
  G4ThreeVector localPos 
    = theTouchable->GetHistory()->GetTopTransform().TransformPoint(worldPos);

  CSCG4ExDriftChamberHit* aHit = new CSCG4ExDriftChamberHit(copyNo);
  aHit->SetWorldPos(worldPos);
  aHit->SetLocalPos(localPos);
  aHit->SetTime(preStepPoint->GetGlobalTime());

  hitsCollection->insert(aHit);

  return true;
}

void CSCG4ExDriftChamber::EndOfEvent(G4HCofThisEvent*HCE)
{;}

