// This code implementation is the intellectual property of
// the GEANT4 collaboration.
//
// By copying, distributing or modifying the Program (or any work
// based on the Program) you indicate your acceptance of this statement,
// and all its terms.
//
#include "CSCG4ExDriftChamberHit.hh"
#include "G4ios.hh"
#include "G4VVisManager.hh"
#include "G4Circle.hh"
#include "G4Colour.hh"
#include "G4VisAttributes.hh"
#include "G4LogicalVolume.hh"

G4Allocator<CSCG4ExDriftChamberHit> CSCG4ExDriftChamberHitAllocator;

CSCG4ExDriftChamberHit::CSCG4ExDriftChamberHit()
{
  layerID = -1;
  time = 0.;
}

CSCG4ExDriftChamberHit::CSCG4ExDriftChamberHit(G4int z)
{
  layerID = z;
  time = 0.;
}

CSCG4ExDriftChamberHit::~CSCG4ExDriftChamberHit()
{;}

CSCG4ExDriftChamberHit::CSCG4ExDriftChamberHit(const CSCG4ExDriftChamberHit &right)
{
  layerID = right.layerID;
  worldPos = right.worldPos;
  localPos = right.localPos;
  time = right.time;
}

const CSCG4ExDriftChamberHit& CSCG4ExDriftChamberHit::operator=(const CSCG4ExDriftChamberHit &right)
{
  layerID = right.layerID;
  worldPos = right.worldPos;
  localPos = right.localPos;
  time = right.time;
  return *this;
}

int CSCG4ExDriftChamberHit::operator==(const CSCG4ExDriftChamberHit &right) const
{
  return 0;
}

void CSCG4ExDriftChamberHit::Draw()
{
  G4VVisManager* pVVisManager = G4VVisManager::GetConcreteInstance();
  if(pVVisManager)
  {
    G4Circle circle(worldPos);
    circle.SetScreenSize(0.1);
    circle.SetFillStyle(G4Circle::filled);
    G4Colour colour(1.,1.,0.);
    G4VisAttributes attribs(colour);
    circle.SetVisAttributes(attribs);
    pVVisManager->Draw(circle);
  }
}

void CSCG4ExDriftChamberHit::Print()
{
  G4cout << "  Layer[" << layerID << "] : time " << time/ns 
         << " (nsec) --- local (x,y) " << localPos.x() 
         << ", " << localPos.y() << G4endl;
}


