// This code implementation is the intellectual property of
// the GEANT4 collaboration.
//
// By copying, distributing or modifying the Program (or any work
// based on the Program) you indicate your acceptance of this statement,
// and all its terms.
//
#include "CSCG4ExEmCalorimeter.hh"
#include "CSCG4ExEmCalorimeterHit.hh"
#include "G4HCofThisEvent.hh"
#include "G4TouchableHistory.hh"
#include "G4Track.hh"
#include "G4Step.hh"
#include "G4SDManager.hh"
#include "G4ios.hh"

CSCG4ExEmCalorimeter::CSCG4ExEmCalorimeter(G4String name)
:G4VSensitiveDetector(name)
{
  G4String HCname;
  collectionName.insert(HCname="EMcalorimeterColl");
  HCID = -1;
}

CSCG4ExEmCalorimeter::~CSCG4ExEmCalorimeter(){;}

void CSCG4ExEmCalorimeter::Initialize(G4HCofThisEvent*HCE)
{
  hitsCollection = new CSCG4ExEmCalorimeterHitsCollection
                   (SensitiveDetectorName,collectionName[0]); 
  if(HCID<0)
  { HCID = G4SDManager::GetSDMpointer()->GetCollectionID(hitsCollection); }
  HCE->AddHitsCollection(HCID,hitsCollection);
  
  // fill calorimeter hits with zero energy deposition
  for(int i=0;i<80;i++)
  {
    CSCG4ExEmCalorimeterHit* aHit = new CSCG4ExEmCalorimeterHit(i);
    hitsCollection->insert( aHit );
  }
}

G4bool CSCG4ExEmCalorimeter::ProcessHits(G4Step*aStep,G4TouchableHistory*ROhist)
{
  G4double edep = aStep->GetTotalEnergyDeposit();
  if(edep==0.) return true;

  G4StepPoint* preStepPoint = aStep->GetPreStepPoint();
  G4TouchableHistory* theTouchable
    = (G4TouchableHistory*)(preStepPoint->GetTouchable());
  G4VPhysicalVolume* thePhysical = theTouchable->GetVolume();
  G4int copyNo = thePhysical->GetCopyNo();

  CSCG4ExEmCalorimeterHit* aHit = (*hitsCollection)[copyNo];
  // check if it is first touch
  if(!(aHit->GetLogV()))
  {
    // fill volume information
    aHit->SetLogV(thePhysical->GetLogicalVolume());
    G4AffineTransform aTrans = theTouchable->GetHistory()->GetTopTransform();
    aTrans.Invert();
    aHit->SetRot(aTrans.NetRotation());
    aHit->SetPos(aTrans.NetTranslation());
  }
  // add energy deposition
  aHit->AddEdep(edep);

  return true;
}

void CSCG4ExEmCalorimeter::EndOfEvent(G4HCofThisEvent*HCE)
{;}

