// This code implementation is the intellectual property of
// the GEANT4 collaboration.
//
// By copying, distributing or modifying the Program (or any work
// based on the Program) you indicate your acceptance of this statement,
// and all its terms.
//

#include "CSCG4ExEmCalorimeterHit.hh"
#include "G4VVisManager.hh"
#include "G4Colour.hh"
#include "G4VisAttributes.hh"
#include "G4LogicalVolume.hh"
#include "G4ios.hh"

G4Allocator<CSCG4ExEmCalorimeterHit> CSCG4ExEmCalorimeterHitAllocator;

CSCG4ExEmCalorimeterHit::CSCG4ExEmCalorimeterHit()
{
  cellID = -1;
  edep = 0.;
  pLogV = 0;
}

CSCG4ExEmCalorimeterHit::CSCG4ExEmCalorimeterHit(G4int z)
{
  cellID = z;
  edep = 0.;
  pLogV = 0;
}

CSCG4ExEmCalorimeterHit::~CSCG4ExEmCalorimeterHit()
{;}

CSCG4ExEmCalorimeterHit::CSCG4ExEmCalorimeterHit(const CSCG4ExEmCalorimeterHit &right)
{
  cellID = right.cellID;
  edep = right.edep;
  pos = right.pos;
  rot = right.rot;
  pLogV = right.pLogV;
}

const CSCG4ExEmCalorimeterHit& CSCG4ExEmCalorimeterHit::operator=(const CSCG4ExEmCalorimeterHit &right)
{
  cellID = right.cellID;
  edep = right.edep;
  pos = right.pos;
  rot = right.rot;
  pLogV = right.pLogV;
  return *this;
}

int CSCG4ExEmCalorimeterHit::operator==(const CSCG4ExEmCalorimeterHit &right) const
{
  return (cellID==right.cellID);
}

void CSCG4ExEmCalorimeterHit::Draw()
{
  G4VVisManager* pVVisManager = G4VVisManager::GetConcreteInstance();
  if(pVVisManager&&(edep>0.))
  {
    // Draw a calorimeter cell with a color corresponding to its energy deposit
    G4Transform3D trans(rot.inverse(),pos);
    G4VisAttributes attribs;
    const G4VisAttributes* pVA = pLogV->GetVisAttributes();
    if(pVA) attribs = *pVA;
    G4double rcol = edep/(0.7*GeV);
    if(rcol>1.) rcol = 1.;
    G4Colour colour(rcol,0.,0.);
    attribs.SetColour(colour);
    attribs.SetForceWireframe(false);
    attribs.SetForceSolid(true);
    pVVisManager->Draw(*pLogV,attribs,trans);
  }
}

void CSCG4ExEmCalorimeterHit::Print()
{
  G4cout << "  Cell[" << cellID << "] " << edep/MeV << " (MeV)" << G4endl;
}


