// This code implementation is the intellectual property of
// the GEANT4 collaboration.
//
// By copying, distributing or modifying the Program (or any work
// based on the Program) you indicate your acceptance of this statement,
// and all its terms.
//

#include "CSCG4ExEventAction.hh"
#include "CSCG4ExEventActionMessenger.hh"

#include "G4Event.hh"
#include "G4EventManager.hh"
#include "G4HCofThisEvent.hh"
#include "G4VHitsCollection.hh"
#include "G4TrajectoryContainer.hh"
#include "G4Trajectory.hh"
#include "G4VVisManager.hh"
#include "G4SDManager.hh"
#include "G4UImanager.hh"
#include "G4ios.hh"

#include "CSCG4ExHodoscopeHit.hh"
#include "CSCG4ExDriftChamberHit.hh"
#include "CSCG4ExEmCalorimeterHit.hh"

//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
#include "MyHadCalorimeterHit.hh"
//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@


CSCG4ExEventAction::CSCG4ExEventAction()
{
  G4String colName;
  G4SDManager* SDman = G4SDManager::GetSDMpointer();
  HHC1ID = SDman->GetCollectionID(colName="hodoscope1/hodoscopeColl");
  HHC2ID = SDman->GetCollectionID(colName="hodoscope2/hodoscopeColl");
  DHC1ID = SDman->GetCollectionID(colName="chamber1/driftChamberColl");
  DHC2ID = SDman->GetCollectionID(colName="chamber2/driftChamberColl");
  ECHCID = SDman->GetCollectionID(colName="EMcalorimeter/EMcalorimeterColl");
//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
  HCHCID = SDman->GetCollectionID(colName="HadCalorimeter/HadCalorimeterColl");
//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
  verboseLevel = 1;
  messenger = new CSCG4ExEventActionMessenger(this);
}

CSCG4ExEventAction::~CSCG4ExEventAction()
{
  delete messenger;
}

void CSCG4ExEventAction::BeginOfEventAction(const G4Event*)
{
}

void CSCG4ExEventAction::EndOfEventAction(const G4Event* evt)
{
  if(verboseLevel==0 || evt->GetEventID() % verboseLevel != 0) return;

  G4PrimaryParticle* primary = evt->GetPrimaryVertex(0)->GetPrimary(0);
  G4cout << G4endl 
         << ">>> Event " << evt->GetEventID() << " >>> Simulation truth : " 
         << primary->GetG4code()->GetParticleName() 
         << " " << primary->GetMomentum() << G4endl;

  G4HCofThisEvent * HCE = evt->GetHCofThisEvent();
  CSCG4ExHodoscopeHitsCollection* HHC1 = NULL;
  CSCG4ExHodoscopeHitsCollection* HHC2 = NULL;
  CSCG4ExDriftChamberHitsCollection* DHC1 = NULL;
  CSCG4ExDriftChamberHitsCollection* DHC2 = NULL;
  CSCG4ExEmCalorimeterHitsCollection* ECHC = NULL;
//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
  MyHadCalorimeterHitsCollection* HCHC = NULL;
//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
  if(HCE)
  {
    HHC1 = (CSCG4ExHodoscopeHitsCollection*)(HCE->GetHC(HHC1ID));
    HHC2 = (CSCG4ExHodoscopeHitsCollection*)(HCE->GetHC(HHC2ID));
    DHC1 = (CSCG4ExDriftChamberHitsCollection*)(HCE->GetHC(DHC1ID));
    DHC2 = (CSCG4ExDriftChamberHitsCollection*)(HCE->GetHC(DHC2ID));
    ECHC = (CSCG4ExEmCalorimeterHitsCollection*)(HCE->GetHC(ECHCID));
//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
    HCHC = (MyHadCalorimeterHitsCollection*)(HCE->GetHC(HCHCID));
//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
  }
  if(HHC1)
  {
    int n_hit = HHC1->entries();
    G4cout << "Hodoscope 1 has " << n_hit << " hits." << G4endl;
    for(int i1=0;i1<n_hit;i1++)
    {
      CSCG4ExHodoscopeHit* aHit = (*HHC1)[i1];
      aHit->Print();
    }
  }
  if(HHC2)
  {
    int n_hit = HHC2->entries();
    G4cout << "Hodoscope 2 has " << n_hit << " hits." << G4endl;
    for(int i1=0;i1<n_hit;i1++)
    {
      CSCG4ExHodoscopeHit* aHit = (*HHC2)[i1];
      aHit->Print();
    }
  }
  if(DHC1)
  {
    int n_hit = DHC1->entries();
    G4cout << "Drift Chamber 1 has " << n_hit << " hits." << G4endl;
    for(int i2=0;i2<5;i2++)
    {
      for(int i1=0;i1<n_hit;i1++)
      {
        CSCG4ExDriftChamberHit* aHit = (*DHC1)[i1];
        if(aHit->GetLayerID()==i2) aHit->Print();
      }
    }
  }
  if(DHC2)
  {
    int n_hit = DHC2->entries();
    G4cout << "Drift Chamber 2 has " << n_hit << " hits." << G4endl;
    for(int i2=0;i2<5;i2++)
    {
      for(int i1=0;i1<n_hit;i1++)
      {
        CSCG4ExDriftChamberHit* aHit = (*DHC2)[i1];
        if(aHit->GetLayerID()==i2) aHit->Print();
      }
    }
  }
  if(ECHC)
  {
    int iHit = 0;
    double totalE = 0.;
    for(int i1=0;i1<80;i1++)
    {
      CSCG4ExEmCalorimeterHit* aHit = (*ECHC)[i1];
      double eDep = aHit->GetEdep();
      if(eDep>0.)
      {
        iHit++;
        totalE += eDep;
      }
    }
    G4cout << "EM Calorimeter has " << iHit << " hits. Total Edep is "
           << totalE/MeV << " (MeV)" << G4endl;
  }
//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@
  if(HCHC)
  {
    int iHit = 0;
    double totalE = 0.;
    for(int i1=0;i1<20;i1++)
    {
      MyHadCalorimeterHit* aHit = (*HCHC)[i1];
      double eDep = aHit->GetEdep();
      if(eDep>0.)
      {
        iHit++;
        totalE += eDep;
      }
    }
    G4cout << "Hadron Calorimeter has " << iHit << " hits. Total Edep is "
           << totalE/MeV << " (MeV)" << G4endl;
  }
//@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@

}



