// This code implementation is the intellectual property of
// the GEANT4 collaboration.
//
// By copying, distributing or modifying the Program (or any work
// based on the Program) you indicate your acceptance of this statement,
// and all its terms.
//

#include "MyHadCalorimeterHit.hh"
#include "CSCG4ExDetectorConstruction.hh"
#include "G4RunManager.hh"
#include "G4RotationMatrix.hh"
#include "G4Box.hh"
#include "G4VVisManager.hh"
#include "G4Colour.hh"
#include "G4VisAttributes.hh"
#include "G4LogicalVolume.hh"
#include "G4ios.hh"

G4Allocator<MyHadCalorimeterHit> MyHadCalorimeterHitAllocator;

MyHadCalorimeterHit::MyHadCalorimeterHit()
{
  columnID = -1;
  rowID = -1;
  edep = 0.;
}

MyHadCalorimeterHit::MyHadCalorimeterHit(G4int iCol,G4int iRow)
{
  columnID = iCol;
  rowID = iRow;
  edep = 0.;
}

MyHadCalorimeterHit::~MyHadCalorimeterHit()
{;}

MyHadCalorimeterHit::MyHadCalorimeterHit(const MyHadCalorimeterHit &right)
{
  columnID = right.columnID;
  rowID = right.rowID;
  edep = right.edep;
  pos = right.pos;
  rot = right.rot;
}

const MyHadCalorimeterHit& MyHadCalorimeterHit::operator=(const MyHadCalorimeterHit &right)
{
  columnID = right.columnID;
  rowID = right.rowID;
  edep = right.edep;
  pos = right.pos;
  rot = right.rot;
  return *this;
}

int MyHadCalorimeterHit::operator==(const MyHadCalorimeterHit &right) const
{
  return (columnID==right.columnID&&rowID==right.rowID);
}

void MyHadCalorimeterHit::Draw()
{
  G4VVisManager* pVVisManager = G4VVisManager::GetConcreteInstance();
  if(pVVisManager&&(edep>0.))
  {
    // Draw a calorimeter cell with depth propotional to the energy deposition
    G4Transform3D trans(rot.inverse(),pos);
    G4VisAttributes attribs;
    G4Colour colour(1.,1.,0.);
    attribs.SetColour(colour);
    attribs.SetForceWireframe(false);
    attribs.SetForceSolid(true);
    G4Box box("dummy",15.*cm,15.*cm,1.*m*edep/(0.1*GeV));
    pVVisManager->Draw(box,attribs,trans);
  }
}

void MyHadCalorimeterHit::Print()
{
  G4cout << "  Cell[" << rowID << ", " << columnID << "] " << edep/MeV << " (MeV) " << pos << G4endl;
}


