// This code implementation is the intellectual property of
// the GEANT4 collaboration.
//
// By copying, distributing or modifying the Program (or any work
// based on the Program) you indicate your acceptance of this statement,
// and all its terms.
//
#ifndef MyHadCalorimeterHit_h
#define MyHadCalorimeterHit_h 1

#include "G4VHit.hh"
#include "G4THitsCollection.hh"
#include "G4Allocator.hh"
#include "G4ThreeVector.hh"
#include "G4LogicalVolume.hh"
#include "G4Transform3D.hh"
#include "G4RotationMatrix.hh"

class MyHadCalorimeterHit : public G4VHit
{
  public:

      MyHadCalorimeterHit();
      MyHadCalorimeterHit(G4int iCol,G4int iRow);
      virtual ~MyHadCalorimeterHit();
      MyHadCalorimeterHit(const MyHadCalorimeterHit &right);
      const MyHadCalorimeterHit& operator=(const MyHadCalorimeterHit &right);
      int operator==(const MyHadCalorimeterHit &right) const;

      inline void *operator new(size_t);
      inline void operator delete(void *aHit);

      virtual void Draw();
      virtual void Print();

  private:
      G4int columnID;
      G4int rowID;
      G4double edep;
      G4ThreeVector pos;
      G4RotationMatrix rot;

  public:
      inline void SetColumnID(G4int z) { columnID = z; }
      inline G4int GetColumnID() const { return columnID; }
      inline void SetRowID(G4int z) { rowID = z; }
      inline G4int GetRowID() const { return rowID; }
      inline void SetEdep(G4double de) { edep = de; }
      inline void AddEdep(G4double de) { edep += de; }
      inline G4double GetEdep() const { return edep; }
      inline void SetPos(G4ThreeVector xyz) { pos = xyz; }
      inline G4ThreeVector GetPos() const { return pos; }
      inline void SetRot(G4RotationMatrix rmat) { rot = rmat; }
      inline G4RotationMatrix GetRot() const { return rot; }

};

typedef G4THitsCollection<MyHadCalorimeterHit> MyHadCalorimeterHitsCollection;

extern G4Allocator<MyHadCalorimeterHit> MyHadCalorimeterHitAllocator;

inline void* MyHadCalorimeterHit::operator new(size_t)
{
  void* aHit;
  aHit = (void*)MyHadCalorimeterHitAllocator.MallocSingle();
  return aHit;
}

inline void MyHadCalorimeterHit::operator delete(void* aHit)
{
  MyHadCalorimeterHitAllocator.FreeSingle((MyHadCalorimeterHit*) aHit);
}

#endif


